/**
 * A Material Design button component.
 *
 * To render a clear Material button on any html page :
 * @example
 * <materials-button>Click me</materials-button>
 *
 * @description
 * You can use any icon from the material-icons collection (https://material.io/tools/icons)
 *
 * Code is available on github: https://github.com/GMV-centravet/materials/tree/master/src/components/button
 *
 * Material Design guidelines: https://material.io/design/components/buttons.html
 */
export declare class Button {
    /** The button color, it can be either :
     *  - a predifined value : 'primary', 'secondary', 'error'.
     *  - an hexa color code : #225566, #CCC.
     *  - a css named color : red, blue.
     */
    color: 'primary' | 'secondary' | 'error' | string;
    /** A material icon name */
    icon?: string;
    /** The button type */
    type: 'button' | 'submit' | 'reset';
    /** Disable the button */
    disabled: boolean;
    /** Render a raised Material button */
    raised: boolean;
    /** Render an unelevated Material button */
    unelevated: boolean;
    /** Render an outlined Material button */
    outlined: boolean;
    /** Render a dense Material button () */
    dense: boolean;
    /** Render a block Material button (Full width) */
    block: boolean;
    private btnEl;
    private getClasses;
    componentDidLoad(): void;
    render(): any;
}
