import { EventEmitter } from '../../stencil-public-runtime';
/**
 * Class that represent a multi-select element
 * composed by a clickable text-field
 * that opens a dialog with a list of checkboxes
 */
export declare class MaterialsMultipleSelect {
    /**
     * Apply low density on the textfield
     */
    dense: boolean;
    /**
     * Adds an icon at the end of the text field
     */
    trailingIcon: string;
    /**
     * Map of options selectable in the dialog
     */
    options: Map<string, string>;
    /**
     * Label displayed for the multi-select
     */
    label: string;
    /**
     * Title displayed in the dialog
     */
    dialogTitle: string;
    /**
     * list of selected elements
     */
    value: string[];
    /**
     * Display selectable elements on many columns according to the max number of elements per columns allowed
     */
    maxElementsColumn: number;
    host: HTMLElement;
    /**
     * Event dispatched when multi-select value changes
     */
    change: EventEmitter;
    private multiSelectInput;
    private multiSelectDialog;
    private multiList;
    componentWillLoad(): void;
    componentWillUpdate(): void;
    computeMultiList(): void;
    componentDidLoad(): void;
    componentDidUpdate(): void;
    /**
     * @param event allows to open dialog when text-field is clicked
     */
    openMultiSelectDialog(event: any): void;
    /**
     * Function called when dialog is accepted
     * emit change event
     * display values selected in text-field
     */
    fillMultiSelectInput(): void;
    /**
     * Function that displays values selected in the text-field
     */
    displayValue(): void;
    /**
     * Function to select or deselect options
     * @param {CustomEvent} event allows to know if options must be selected or deselected
     * @param {string} option to select or deselect
     */
    toggleOption(event: CustomEvent, option: string): void;
    render(): any[];
}
