import { EventEmitter } from '../../stencil-public-runtime';
export declare class TimeField {
    private materialsMenuTimepickerEl;
    private materialsTextFieldEl;
    /** Emitted when the input text change */
    input: EventEmitter;
    /**
     * Styles the date field as a full width text field.
     * Warning : do not use with outlined
     */
    fullwidth: boolean;
    /** Styles the date field as a dense text field. */
    dense: boolean;
    /** Render an outlined date field */
    outlined: boolean;
    /** Styles the date field as a text field in focus. */
    focused: boolean;
    /** Styles the date field as a disabled text field. */
    disabled: boolean;
    /**
     * Add a leading icon to ths date field.
     * You have to pass a material icon name
     */
    leadingIcon: string;
    /** The date field label. */
    label: string;
    /** Mark this date field as required */
    required: boolean;
    /** The date field value */
    value: any;
    /** The date field width */
    width: number;
    /** Add an helper text to this date field */
    helperText: string;
    /** Set the helper text persistant (appears on focus otherwise) */
    persistent: boolean;
    /** Display a timepicker when clicking on the time-field */
    timepicker: boolean;
    /** The timepicker options interval (in minutes) */
    timepickerStep: number;
    /** The timepicker format */
    timepickerFormat: '12h' | '24h';
    /**
     * Provide a custom validation function to this time-field.
     * In case of error, the promise should return a message with the
     * error message to display
     */
    customValidation: () => Promise<string>;
    /** Return the time-field current value validity */
    isValid(): Promise<boolean>;
    /** Force the validation of thid time field (native validation + custom validation) */
    forceValidation(): Promise<void>;
    componentWillLoad(): void;
    updateValue(): void;
    private renderTimePicker;
    private openPicker;
    render(): any;
}
