'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-42b107ae.js');
require('./component-9b142814.js');
require('./ponyfill-32fd2054.js');
require('./component-3a63b4ac.js');
const component$2 = require('./component-490caf09.js');
const index$1 = require('./index-558a2b3e.js');

const TextField = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /** Hide clear button (webkit + Edge, Moz not supported) */
        this.hideNativeClear = false;
        // Input
        this.type = 'text';
        this.input = index.createEvent(this, "input", 7);
        this.change = index.createEvent(this, "change", 7);
        this.trailingIconPress = index.createEvent(this, "trailingIconPress", 7);
        this.leadingIconPress = index.createEvent(this, "leadingIconPress", 7);
    }
    componentWillLoad() {
        if (!this.value) {
            this.value = '';
        }
    }
    async updateValue() {
        if (!this.value) {
            this.value = '';
            return;
        }
        if (this.mdcTextField) {
            this.mdcTextField.value = this.value;
            await this.forceValidation();
        }
    }
    componentDidLoad() {
        this.mdcTextField = new index$1.MDCTextField(this.textFieldEl);
        this.mdcTextField.useNativeValidation = false;
        if (this.label) {
            component$2.MDCFloatingLabel.attachTo(this.floatingLabelEl);
        }
        this.mdcTextFieldHelperText = new index$1.MDCTextFieldHelperText(this.helperTextEl);
        this.mdcTextFieldHelperText.foundation.setContent(this.helperText);
        this.mdcTextFieldHelperText.foundation.setPersistent(this.persistent);
        if (this.outlined) {
            component$2.MDCNotchedOutline.attachTo(this.notchedOutlineEl);
        }
        else {
            component$2.MDCLineRipple.attachTo(this.lineRippleEl);
        }
        if (this.leadingIcon && this.leadingIconPress) {
            index$1.MDCTextFieldIcon.attachTo(this.host.shadowRoot.querySelector('.materials-leading-icon'));
        }
        if (this.trailingIcon && this.trailingIconPress) {
            index$1.MDCTextFieldIcon.attachTo(this.host.shadowRoot.querySelector('.materials-trailing-icon'));
        }
    }
    getClasses() {
        return {
            'mdc-text-field': true,
            'mdc-text-field--disabled': this.disabled,
            'mdc-text-field--fullwidth': this.fullwidth,
            'mdc-text-field--outlined': this.outlined,
            'mdc-text-field--focused': this.focused,
            'mdc-text-field--no-label': !this.label,
            'mdc-text-field--with-leading-icon': !!this.leadingIcon,
            'mdc-text-field--with-trailing-icon': !!this.trailingIcon
        };
    }
    getLabelClasses() {
        return {
            'mdc-floating-label': true
        };
    }
    async isValid() {
        const nativeValidation = this.inputEl.validity.valid;
        if (!nativeValidation) {
            return false;
        }
        if (this.customValidation) {
            return !(await this.customValidation());
        }
        return true;
    }
    async forceValidation() {
        const nativeValidation = this.inputEl.validity.valid;
        if (!nativeValidation) {
            this.mdcTextField.valid = false;
            this.mdcTextFieldHelperText.foundation.setContent(this.inputEl.validationMessage);
            this.mdcTextFieldHelperText.foundation.setValidation(true);
            this.realHelperText = this.inputEl.validationMessage;
            return;
        }
        if (this.customValidation) {
            const validatonMessage = await this.customValidation();
            if (validatonMessage) {
                this.mdcTextField.valid = false;
                this.mdcTextFieldHelperText.foundation.setContent(validatonMessage);
                this.mdcTextFieldHelperText.foundation.setValidation(true);
                this.realHelperText = validatonMessage;
                return;
            }
        }
        this.mdcTextField.valid = true;
        this.mdcTextFieldHelperText.foundation.setContent(this.helperText);
        this.mdcTextFieldHelperText.foundation.setValidation(false);
        this.realHelperText = this.helperText;
    }
    render() {
        return (index.h(index.Host, { class: { 'materials-text-field--dense': this.dense } }, index.h("div", { style: { 'width': this.width ? (this.width + 'px') : '100%' }, class: this.getClasses(), ref: mdcTextField => this.textFieldEl = mdcTextField }, this.leadingIcon &&
            index.h("i", { class: "materials-leading-icon material-icons mdc-text-field__icon", title: this.leadingIconTitle, onClick: (ev) => this.leadingIconPress.emit(ev), tabindex: "0", role: "button" }, this.leadingIcon), index.h("input", { id: "my-text-field", class: { 'mdc-text-field__input': true, 'hide-native-clear': this.hideNativeClear, 'mdc-text-field--overflow-elipsis': this.overflow }, type: this.type, pattern: this.pattern, value: this.value, disabled: this.disabled, required: this.required, readonly: this.readonly, name: this.name, maxlength: this.maxlength, ref: el => this.inputEl = el, onInput: (ev) => {
                this.value = ev.target.value;
                this.input.emit(ev);
            }, onChange: (ev) => this.change.emit(ev) }), this.trailingIcon &&
            index.h("i", { onClick: (ev) => this.trailingIconPress.emit(ev), class: "materials-trailing-icon material-icons mdc-text-field__icon", title: this.trailingIconTitle, tabindex: "0", role: "button" }, this.trailingIcon), this.outlined ?
            index.h("div", { class: "mdc-notched-outline", ref: notchedOutlineEl => this.notchedOutlineEl = notchedOutlineEl }, index.h("div", { class: "mdc-notched-outline__leading" }), index.h("div", { class: "mdc-notched-outline__notch" }, this.label && index.h("label", { class: this.getLabelClasses(), ref: el => this.floatingLabelEl = el }, this.label)), index.h("div", { class: "mdc-notched-outline__trailing" }))
            : this.label && index.h("label", { class: this.getLabelClasses(), ref: el => this.floatingLabelEl = el }, this.label), this.outlined ? '' : index.h("div", { class: "mdc-line-ripple", ref: el => this.lineRippleEl = el })), index.h("div", { class: "mdc-text-field-helper-line" }, index.h("div", { id: "helper-text", class: { 'mdc-text-field-helper-text': true }, "aria-hidden": "true", ref: el => this.helperTextEl = el }))));
    }
    get host() { return index.getElement(this); }
    static get watchers() { return {
        "value": ["updateValue"]
    }; }
    static get style() { return ".mdc-floating-label{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.75rem;font-weight:400;letter-spacing:0.009375em;text-decoration:inherit;text-transform:inherit;position:absolute;left:0;-webkit-transform-origin:left top;transform-origin:left top;-webkit-transition:color 150ms cubic-bezier(0.4,0,0.2,1),-webkit-transform 150ms cubic-bezier(0.4,0,0.2,1);transition:color 150ms cubic-bezier(0.4,0,0.2,1),-webkit-transform 150ms cubic-bezier(0.4,0,0.2,1);transition:transform 150ms cubic-bezier(0.4,0,0.2,1),color 150ms cubic-bezier(0.4,0,0.2,1);transition:transform 150ms cubic-bezier(0.4,0,0.2,1),color 150ms cubic-bezier(0.4,0,0.2,1),-webkit-transform 150ms cubic-bezier(0.4,0,0.2,1);line-height:1.15rem;text-align:left;text-overflow:ellipsis;white-space:nowrap;cursor:text;overflow:hidden;will-change:transform;}[dir=rtl] .mdc-floating-label,.mdc-floating-label[dir=rtl]{right:0;left:auto;-webkit-transform-origin:right top;transform-origin:right top;text-align:right;}.mdc-floating-label--float-above{cursor:auto;}.mdc-floating-label--float-above{-webkit-transform:translateY(-50%) scale(0.75);transform:translateY(-50%) scale(0.75);}.mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-standard 250ms 1;animation:mdc-floating-label-shake-float-above-standard 250ms 1;}\@-webkit-keyframes mdc-floating-label-shake-float-above-standard{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(4% - 0%)) translateY(-50%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(-4% - 0%)) translateY(-50%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);}}\@keyframes mdc-floating-label-shake-float-above-standard{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(4% - 0%)) translateY(-50%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(-4% - 0%)) translateY(-50%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-50%) scale(0.75);}}.mdc-line-ripple{position:absolute;bottom:0;left:0;width:100%;height:2px;-webkit-transform:scaleX(0);transform:scaleX(0);-webkit-transition:opacity 180ms cubic-bezier(0.4,0,0.2,1),-webkit-transform 180ms cubic-bezier(0.4,0,0.2,1);transition:opacity 180ms cubic-bezier(0.4,0,0.2,1),-webkit-transform 180ms cubic-bezier(0.4,0,0.2,1);transition:transform 180ms cubic-bezier(0.4,0,0.2,1),opacity 180ms cubic-bezier(0.4,0,0.2,1);transition:transform 180ms cubic-bezier(0.4,0,0.2,1),opacity 180ms cubic-bezier(0.4,0,0.2,1),-webkit-transform 180ms cubic-bezier(0.4,0,0.2,1);opacity:0;z-index:2;}.mdc-line-ripple--active{-webkit-transform:scaleX(1);transform:scaleX(1);opacity:1;}.mdc-line-ripple--deactivating{opacity:0;}.mdc-notched-outline{display:-ms-flexbox;display:flex;position:absolute;right:0;left:0;-webkit-box-sizing:border-box;box-sizing:border-box;width:100%;max-width:100%;height:100%;text-align:left;pointer-events:none;}[dir=rtl] .mdc-notched-outline,.mdc-notched-outline[dir=rtl]{text-align:right;}.mdc-notched-outline__leading,.mdc-notched-outline__notch,.mdc-notched-outline__trailing{-webkit-box-sizing:border-box;box-sizing:border-box;height:100%;-webkit-transition:border 150ms cubic-bezier(0.4,0,0.2,1);transition:border 150ms cubic-bezier(0.4,0,0.2,1);border-top:1px solid;border-bottom:1px solid;pointer-events:none;}.mdc-notched-outline__leading{border-left:1px solid;border-right:none;width:12px;}[dir=rtl] .mdc-notched-outline__leading,.mdc-notched-outline__leading[dir=rtl]{border-left:none;border-right:1px solid;}.mdc-notched-outline__trailing{border-left:none;border-right:1px solid;-ms-flex-positive:1;flex-grow:1;}[dir=rtl] .mdc-notched-outline__trailing,.mdc-notched-outline__trailing[dir=rtl]{border-left:1px solid;border-right:none;}.mdc-notched-outline__notch{-ms-flex:0 0 auto;flex:0 0 auto;width:auto;max-width:calc(100% - 12px * 2);}.mdc-notched-outline .mdc-floating-label{display:inline-block;position:relative;top:17px;bottom:auto;max-width:100%;}.mdc-notched-outline .mdc-floating-label--float-above{text-overflow:clip;}.mdc-notched-outline--upgraded .mdc-floating-label--float-above{max-width:calc(100% / .75);}.mdc-notched-outline--notched .mdc-notched-outline__notch{padding-left:0;padding-right:8px;border-top:none;}[dir=rtl] .mdc-notched-outline--notched .mdc-notched-outline__notch,.mdc-notched-outline--notched .mdc-notched-outline__notch[dir=rtl]{padding-left:8px;padding-right:0;}.mdc-notched-outline--no-label .mdc-notched-outline__notch{padding:0;}\@-webkit-keyframes mdc-ripple-fg-radius-in{from{-webkit-animation-timing-function:cubic-bezier(0.4,0,0.2,1);animation-timing-function:cubic-bezier(0.4,0,0.2,1);-webkit-transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);}to{-webkit-transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));}}\@keyframes mdc-ripple-fg-radius-in{from{-webkit-animation-timing-function:cubic-bezier(0.4,0,0.2,1);animation-timing-function:cubic-bezier(0.4,0,0.2,1);-webkit-transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);}to{-webkit-transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));}}\@-webkit-keyframes mdc-ripple-fg-opacity-in{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:0;}to{opacity:var(--mdc-ripple-fg-opacity,0);}}\@keyframes mdc-ripple-fg-opacity-in{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:0;}to{opacity:var(--mdc-ripple-fg-opacity,0);}}\@-webkit-keyframes mdc-ripple-fg-opacity-out{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:var(--mdc-ripple-fg-opacity,0);}to{opacity:0;}}\@keyframes mdc-ripple-fg-opacity-out{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:var(--mdc-ripple-fg-opacity,0);}to{opacity:0;}}.mdc-ripple-surface--test-edge-var-bug{--mdc-ripple-surface-test-edge-var:1px solid #000;visibility:hidden;}.mdc-ripple-surface--test-edge-var-bug::before{border:var(--mdc-ripple-surface-test-edge-var);}.mdc-text-field-helper-text{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.75rem;line-height:1.25rem;font-weight:400;letter-spacing:0.0333333333em;text-decoration:inherit;text-transform:inherit;display:block;margin-top:0;line-height:normal;margin:0;-webkit-transition:opacity 150ms cubic-bezier(0.4,0,0.2,1);transition:opacity 150ms cubic-bezier(0.4,0,0.2,1);opacity:0;will-change:opacity;}.mdc-text-field-helper-text::before{display:inline-block;width:0;height:16px;content:\"\";vertical-align:0;}.mdc-text-field-helper-text--persistent{-webkit-transition:none;transition:none;opacity:1;will-change:initial;}.mdc-text-field-character-counter{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.75rem;line-height:1.25rem;font-weight:400;letter-spacing:0.0333333333em;text-decoration:inherit;text-transform:inherit;display:block;margin-top:0;line-height:normal;margin-left:auto;margin-right:0;padding-left:16px;padding-right:0;white-space:nowrap;}.mdc-text-field-character-counter::before{display:inline-block;width:0;height:16px;content:\"\";vertical-align:0;}[dir=rtl] .mdc-text-field-character-counter,.mdc-text-field-character-counter[dir=rtl]{margin-left:0;margin-right:auto;}[dir=rtl] .mdc-text-field-character-counter,.mdc-text-field-character-counter[dir=rtl]{padding-left:0;padding-right:16px;}.mdc-text-field--with-leading-icon .mdc-text-field__icon,.mdc-text-field--with-trailing-icon .mdc-text-field__icon{position:absolute;bottom:16px;cursor:pointer;}.mdc-text-field__icon:not([tabindex]),.mdc-text-field__icon[tabindex=\"-1\"]{cursor:default;pointer-events:none;}.mdc-text-field{--mdc-ripple-fg-size:0;--mdc-ripple-left:0;--mdc-ripple-top:0;--mdc-ripple-fg-scale:1;--mdc-ripple-fg-translate-end:0;--mdc-ripple-fg-translate-start:0;-webkit-tap-highlight-color:rgba(0,0,0,0);border-radius:4px 4px 0 0;display:-ms-inline-flexbox;display:inline-flex;position:relative;-webkit-box-sizing:border-box;box-sizing:border-box;height:56px;overflow:hidden;will-change:opacity,transform,color;}.mdc-text-field::before,.mdc-text-field::after{position:absolute;border-radius:50%;opacity:0;pointer-events:none;content:\"\";}.mdc-text-field::before{-webkit-transition:opacity 15ms linear,background-color 15ms linear;transition:opacity 15ms linear,background-color 15ms linear;z-index:1;}.mdc-text-field.mdc-ripple-upgraded::before{-webkit-transform:scale(var(--mdc-ripple-fg-scale,1));transform:scale(var(--mdc-ripple-fg-scale,1));}.mdc-text-field.mdc-ripple-upgraded::after{top:0;left:0;-webkit-transform:scale(0);transform:scale(0);-webkit-transform-origin:center center;transform-origin:center center;}.mdc-text-field.mdc-ripple-upgraded--unbounded::after{top:var(--mdc-ripple-top,0);left:var(--mdc-ripple-left,0);}.mdc-text-field.mdc-ripple-upgraded--foreground-activation::after{-webkit-animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards;animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards;}.mdc-text-field.mdc-ripple-upgraded--foreground-deactivation::after{-webkit-animation:mdc-ripple-fg-opacity-out 150ms;animation:mdc-ripple-fg-opacity-out 150ms;-webkit-transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));}.mdc-text-field::before,.mdc-text-field::after{background-color:rgba(0,0,0,0.87);}.mdc-text-field:hover::before{opacity:0.04;}.mdc-text-field:not(.mdc-ripple-upgraded):focus::before,.mdc-text-field.mdc-ripple-upgraded--background-focused::before{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}.mdc-text-field::before,.mdc-text-field::after{top:calc(50% - 100%);left:calc(50% - 100%);width:200%;height:200%;}.mdc-text-field.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size,100%);height:var(--mdc-ripple-fg-size,100%);}.mdc-text-field:not(.mdc-text-field--disabled) .mdc-floating-label{color:rgba(0,0,0,0.6);}.mdc-text-field:not(.mdc-text-field--disabled) .mdc-text-field__input{color:rgba(0,0,0,0.87);}.mdc-text-field .mdc-text-field__input{caret-color:#6200ee;caret-color:var(--mdc-theme-primary,#6200ee);}.mdc-text-field:not(.mdc-text-field--disabled):not(.mdc-text-field--outlined):not(.mdc-text-field--textarea) .mdc-text-field__input{border-bottom-color:rgba(0,0,0,0.42);}.mdc-text-field:not(.mdc-text-field--disabled):not(.mdc-text-field--outlined):not(.mdc-text-field--textarea) .mdc-text-field__input:hover{border-bottom-color:rgba(0,0,0,0.87);}.mdc-text-field .mdc-line-ripple{background-color:#6200ee;background-color:var(--mdc-theme-primary,#6200ee);}.mdc-text-field:not(.mdc-text-field--disabled):not(.mdc-text-field--textarea){border-bottom-color:rgba(0,0,0,0.12);}.mdc-text-field:not(.mdc-text-field--disabled)+.mdc-text-field-helper-line .mdc-text-field-helper-text{color:rgba(0,0,0,0.6);}.mdc-text-field:not(.mdc-text-field--disabled) .mdc-text-field-character-counter,.mdc-text-field:not(.mdc-text-field--disabled)+.mdc-text-field-helper-line .mdc-text-field-character-counter{color:rgba(0,0,0,0.6);}.mdc-text-field:not(.mdc-text-field--disabled) .mdc-text-field__icon{color:rgba(0,0,0,0.54);}.mdc-text-field:not(.mdc-text-field--disabled){background-color:whitesmoke;}.mdc-text-field .mdc-floating-label{left:16px;right:initial;top:18px;pointer-events:none;}[dir=rtl] .mdc-text-field .mdc-floating-label,.mdc-text-field .mdc-floating-label[dir=rtl]{left:initial;right:16px;}.mdc-text-field--textarea .mdc-floating-label{left:4px;right:initial;}[dir=rtl] .mdc-text-field--textarea .mdc-floating-label,.mdc-text-field--textarea .mdc-floating-label[dir=rtl]{left:initial;right:4px;}.mdc-text-field--outlined .mdc-floating-label{left:4px;right:initial;top:17px;}[dir=rtl] .mdc-text-field--outlined .mdc-floating-label,.mdc-text-field--outlined .mdc-floating-label[dir=rtl]{left:initial;right:4px;}.mdc-text-field--outlined--with-leading-icon .mdc-floating-label{left:36px;right:initial;}[dir=rtl] .mdc-text-field--outlined--with-leading-icon .mdc-floating-label,.mdc-text-field--outlined--with-leading-icon .mdc-floating-label[dir=rtl]{left:initial;right:36px;}.mdc-text-field--outlined--with-leading-icon .mdc-floating-label--float-above{left:40px;right:initial;}[dir=rtl] .mdc-text-field--outlined--with-leading-icon .mdc-floating-label--float-above,.mdc-text-field--outlined--with-leading-icon .mdc-floating-label--float-above[dir=rtl]{left:initial;right:40px;}.mdc-text-field__input{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.75rem;font-weight:400;letter-spacing:0.009375em;text-decoration:inherit;text-transform:inherit;-ms-flex-item-align:end;align-self:flex-end;-webkit-box-sizing:border-box;box-sizing:border-box;width:100%;height:100%;padding:20px 16px 6px;-webkit-transition:opacity 150ms cubic-bezier(0.4,0,0.2,1);transition:opacity 150ms cubic-bezier(0.4,0,0.2,1);border:none;border-bottom:1px solid;border-radius:0;background:none;-webkit-appearance:none;-moz-appearance:none;appearance:none;}.mdc-text-field__input::-webkit-input-placeholder{-webkit-transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);opacity:0;color:rgba(0,0,0,0.54);}.mdc-text-field__input::-moz-placeholder{-moz-transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);opacity:0;color:rgba(0,0,0,0.54);}.mdc-text-field__input:-ms-input-placeholder{-ms-transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);opacity:0;color:rgba(0,0,0,0.54);}.mdc-text-field__input::-ms-input-placeholder{-ms-transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);opacity:0;color:rgba(0,0,0,0.54);}.mdc-text-field__input::placeholder{-webkit-transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);transition:opacity 67ms cubic-bezier(0.4,0,0.2,1);opacity:0;color:rgba(0,0,0,0.54);}.mdc-text-field__input:-ms-input-placeholder{color:rgba(0,0,0,0.54) !important;}.mdc-text-field--fullwidth .mdc-text-field__input::-webkit-input-placeholder,.mdc-text-field--no-label .mdc-text-field__input::-webkit-input-placeholder,.mdc-text-field--focused .mdc-text-field__input::-webkit-input-placeholder{-webkit-transition-delay:40ms;transition-delay:40ms;-webkit-transition-duration:110ms;transition-duration:110ms;opacity:1;}.mdc-text-field--fullwidth .mdc-text-field__input::-moz-placeholder,.mdc-text-field--no-label .mdc-text-field__input::-moz-placeholder,.mdc-text-field--focused .mdc-text-field__input::-moz-placeholder{transition-delay:40ms;transition-duration:110ms;opacity:1;}.mdc-text-field--fullwidth .mdc-text-field__input:-ms-input-placeholder,.mdc-text-field--no-label .mdc-text-field__input:-ms-input-placeholder,.mdc-text-field--focused .mdc-text-field__input:-ms-input-placeholder{transition-delay:40ms;transition-duration:110ms;opacity:1;}.mdc-text-field--fullwidth .mdc-text-field__input::-ms-input-placeholder,.mdc-text-field--no-label .mdc-text-field__input::-ms-input-placeholder,.mdc-text-field--focused .mdc-text-field__input::-ms-input-placeholder{transition-delay:40ms;transition-duration:110ms;opacity:1;}.mdc-text-field--fullwidth .mdc-text-field__input::placeholder,.mdc-text-field--no-label .mdc-text-field__input::placeholder,.mdc-text-field--focused .mdc-text-field__input::placeholder{-webkit-transition-delay:40ms;transition-delay:40ms;-webkit-transition-duration:110ms;transition-duration:110ms;opacity:1;}.mdc-text-field__input:focus{outline:none;}.mdc-text-field__input:invalid{-webkit-box-shadow:none;box-shadow:none;}.mdc-text-field__input:-webkit-autofill{z-index:auto !important;}.mdc-text-field--no-label:not(.mdc-text-field--outlined):not(.mdc-text-field--textarea) .mdc-text-field__input{padding-top:16px;padding-bottom:16px;}.mdc-text-field__input:-webkit-autofill+.mdc-floating-label{-webkit-transform:translateY(-50%) scale(0.75);transform:translateY(-50%) scale(0.75);cursor:auto;}.mdc-text-field--outlined{border:none;overflow:visible;}.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline__trailing{border-color:rgba(0,0,0,0.24);}.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing{border-color:rgba(0,0,0,0.87);}.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__trailing{border-color:#6200ee;border-color:var(--mdc-theme-primary,#6200ee);}.mdc-text-field--outlined .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-outlined 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-outlined 250ms 1;}.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading{border-radius:4px 0 0 4px;}[dir=rtl] .mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading[dir=rtl]{border-radius:0 4px 4px 0;}.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing{border-radius:0 4px 4px 0;}[dir=rtl] .mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing[dir=rtl]{border-radius:4px 0 0 4px;}.mdc-text-field--outlined .mdc-floating-label--float-above{-webkit-transform:translateY(-144%) scale(1);transform:translateY(-144%) scale(1);}.mdc-text-field--outlined .mdc-floating-label--float-above{font-size:0.75rem;}.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{-webkit-transform:translateY(-130%) scale(0.75);transform:translateY(-130%) scale(0.75);}.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem;}.mdc-text-field--outlined::before,.mdc-text-field--outlined::after{content:none;}.mdc-text-field--outlined:not(.mdc-text-field--disabled){background-color:transparent;}.mdc-text-field--outlined .mdc-text-field__input{display:-ms-flexbox;display:flex;padding:12px 16px 14px;border:none !important;background-color:transparent;z-index:1;}.mdc-text-field--outlined .mdc-text-field__icon{z-index:2;}.mdc-text-field--outlined.mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--focused .mdc-notched-outline__trailing{border-width:2px;}.mdc-text-field--outlined.mdc-text-field--disabled{background-color:transparent;}.mdc-text-field--outlined.mdc-text-field--disabled .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--disabled .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--disabled .mdc-notched-outline__trailing{border-color:rgba(0,0,0,0.06);}.mdc-text-field--outlined.mdc-text-field--disabled .mdc-text-field__input{border-bottom:none;}.mdc-text-field--outlined.mdc-text-field--dense{height:48px;}.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--float-above{-webkit-transform:translateY(-134%) scale(1);transform:translateY(-134%) scale(1);}.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--float-above{font-size:0.8rem;}.mdc-text-field--outlined.mdc-text-field--dense.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--outlined.mdc-text-field--dense .mdc-notched-outline--upgraded .mdc-floating-label--float-above{-webkit-transform:translateY(-120%) scale(0.8);transform:translateY(-120%) scale(0.8);}.mdc-text-field--outlined.mdc-text-field--dense.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--outlined.mdc-text-field--dense .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem;}.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-outlined-dense 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-outlined-dense 250ms 1;}.mdc-text-field--outlined.mdc-text-field--dense .mdc-text-field__input{padding:12px 12px 7px;}.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label{top:14px;}.mdc-text-field--outlined.mdc-text-field--dense .mdc-text-field__icon{top:12px;}.mdc-text-field--with-leading-icon .mdc-text-field__icon{left:16px;right:initial;}[dir=rtl] .mdc-text-field--with-leading-icon .mdc-text-field__icon,.mdc-text-field--with-leading-icon .mdc-text-field__icon[dir=rtl]{left:initial;right:16px;}.mdc-text-field--with-leading-icon .mdc-text-field__input{padding-left:48px;padding-right:16px;}[dir=rtl] .mdc-text-field--with-leading-icon .mdc-text-field__input,.mdc-text-field--with-leading-icon .mdc-text-field__input[dir=rtl]{padding-left:16px;padding-right:48px;}.mdc-text-field--with-leading-icon .mdc-floating-label{left:48px;right:initial;}[dir=rtl] .mdc-text-field--with-leading-icon .mdc-floating-label,.mdc-text-field--with-leading-icon .mdc-floating-label[dir=rtl]{left:initial;right:48px;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-text-field__icon{left:16px;right:initial;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-text-field__icon,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-text-field__icon[dir=rtl]{left:initial;right:16px;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-text-field__input{padding-left:48px;padding-right:16px;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-text-field__input,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-text-field__input[dir=rtl]{padding-left:16px;padding-right:48px;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above{-webkit-transform:translateY(-144%) translateX(-32px) scale(1);transform:translateY(-144%) translateX(-32px) scale(1);}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above[dir=rtl]{-webkit-transform:translateY(-144%) translateX(32px) scale(1);transform:translateY(-144%) translateX(32px) scale(1);}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above{font-size:0.75rem;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{-webkit-transform:translateY(-130%) translateX(-32px) scale(0.75);transform:translateY(-130%) translateX(-32px) scale(0.75);}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above[dir=rtl],[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above[dir=rtl]{-webkit-transform:translateY(-130%) translateX(32px) scale(0.75);transform:translateY(-130%) translateX(32px) scale(0.75);}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon 250ms 1;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--shake,.mdc-text-field--with-leading-icon.mdc-text-field--outlined[dir=rtl] .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-rtl 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-rtl 250ms 1;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label{left:36px;right:initial;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label[dir=rtl]{left:initial;right:36px;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--float-above{-webkit-transform:translateY(-134%) translateX(-21px) scale(1);transform:translateY(-134%) translateX(-21px) scale(1);}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--float-above[dir=rtl]{-webkit-transform:translateY(-134%) translateX(21px) scale(1);transform:translateY(-134%) translateX(21px) scale(1);}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--float-above{font-size:0.8rem;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-notched-outline--upgraded .mdc-floating-label--float-above{-webkit-transform:translateY(-120%) translateX(-21px) scale(0.8);transform:translateY(-120%) translateX(-21px) scale(0.8);}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense.mdc-notched-outline--upgraded .mdc-floating-label--float-above[dir=rtl],[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-notched-outline--upgraded .mdc-floating-label--float-above[dir=rtl]{-webkit-transform:translateY(-120%) translateX(21px) scale(0.8);transform:translateY(-120%) translateX(21px) scale(0.8);}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense 250ms 1;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label--shake,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense[dir=rtl] .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense-rtl 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense-rtl 250ms 1;}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label{left:32px;right:initial;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-text-field--dense .mdc-floating-label[dir=rtl]{left:initial;right:32px;}.mdc-text-field--with-trailing-icon .mdc-text-field__icon{left:initial;right:12px;}[dir=rtl] .mdc-text-field--with-trailing-icon .mdc-text-field__icon,.mdc-text-field--with-trailing-icon .mdc-text-field__icon[dir=rtl]{left:12px;right:initial;}.mdc-text-field--with-trailing-icon .mdc-text-field__input{padding-left:16px;padding-right:48px;}[dir=rtl] .mdc-text-field--with-trailing-icon .mdc-text-field__input,.mdc-text-field--with-trailing-icon .mdc-text-field__input[dir=rtl]{padding-left:48px;padding-right:16px;}.mdc-text-field--with-trailing-icon.mdc-text-field--outlined .mdc-text-field__icon{left:initial;right:16px;}[dir=rtl] .mdc-text-field--with-trailing-icon.mdc-text-field--outlined .mdc-text-field__icon,.mdc-text-field--with-trailing-icon.mdc-text-field--outlined .mdc-text-field__icon[dir=rtl]{left:16px;right:initial;}.mdc-text-field--with-trailing-icon.mdc-text-field--outlined .mdc-text-field__input{padding-left:16px;padding-right:48px;}[dir=rtl] .mdc-text-field--with-trailing-icon.mdc-text-field--outlined .mdc-text-field__input,.mdc-text-field--with-trailing-icon.mdc-text-field--outlined .mdc-text-field__input[dir=rtl]{padding-left:48px;padding-right:16px;}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__icon{left:16px;right:auto;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__icon,.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__icon[dir=rtl]{left:auto;right:16px;}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__icon ~ .mdc-text-field__icon{right:12px;left:auto;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__icon ~ .mdc-text-field__icon,.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__icon ~ .mdc-text-field__icon[dir=rtl]{right:auto;left:12px;}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__input{padding-left:48px;padding-right:48px;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__input,.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon .mdc-text-field__input[dir=rtl]{padding-left:48px;padding-right:48px;}.mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-text-field__icon,.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon{bottom:16px;-webkit-transform:scale(0.8);transform:scale(0.8);}.mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-text-field__icon{left:12px;right:initial;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-text-field__icon,.mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-text-field__icon[dir=rtl]{left:initial;right:12px;}.mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-text-field__input{padding-left:44px;padding-right:16px;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-text-field__input,.mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-text-field__input[dir=rtl]{padding-left:16px;padding-right:44px;}.mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-floating-label{left:44px;right:initial;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-floating-label,.mdc-text-field--with-leading-icon.mdc-text-field--dense .mdc-floating-label[dir=rtl]{left:initial;right:44px;}.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon{left:initial;right:12px;}[dir=rtl] .mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon,.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon[dir=rtl]{left:12px;right:initial;}.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__input{padding-left:16px;padding-right:44px;}[dir=rtl] .mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__input,.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__input[dir=rtl]{padding-left:44px;padding-right:16px;}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon{left:12px;right:auto;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon,.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon[dir=rtl]{left:auto;right:12px;}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon ~ .mdc-text-field__icon{right:12px;left:auto;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon ~ .mdc-text-field__icon,.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__icon ~ .mdc-text-field__icon[dir=rtl]{right:auto;left:12px;}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__input{padding-left:44px;padding-right:44px;}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__input,.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--dense .mdc-text-field__input[dir=rtl]{padding-left:44px;padding-right:44px;}.mdc-text-field--dense .mdc-floating-label--float-above{-webkit-transform:translateY(-70%) scale(0.8);transform:translateY(-70%) scale(0.8);}.mdc-text-field--dense .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-dense 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-dense 250ms 1;}.mdc-text-field--dense .mdc-text-field__input{padding:12px 12px 0;}.mdc-text-field--dense .mdc-floating-label{font-size:0.813rem;}.mdc-text-field--dense .mdc-floating-label--float-above{font-size:0.813rem;}.mdc-text-field__input:required ~ .mdc-floating-label::after,.mdc-text-field__input:required ~ .mdc-notched-outline .mdc-floating-label::after{margin-left:1px;content:\"*\";}.mdc-text-field--textarea{display:-ms-inline-flexbox;display:inline-flex;width:auto;height:auto;-webkit-transition:none;transition:none;overflow:visible;}.mdc-text-field--textarea:not(.mdc-text-field--disabled) .mdc-notched-outline__leading,.mdc-text-field--textarea:not(.mdc-text-field--disabled) .mdc-notched-outline__notch,.mdc-text-field--textarea:not(.mdc-text-field--disabled) .mdc-notched-outline__trailing{border-color:rgba(0,0,0,0.24);}.mdc-text-field--textarea:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--textarea:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--textarea:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--textarea:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--textarea:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--textarea:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing{border-color:rgba(0,0,0,0.87);}.mdc-text-field--textarea:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--textarea:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--textarea:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__trailing{border-color:#6200ee;border-color:var(--mdc-theme-primary,#6200ee);}.mdc-text-field--textarea .mdc-floating-label--shake{-webkit-animation:mdc-floating-label-shake-float-above-text-field-outlined 250ms 1;animation:mdc-floating-label-shake-float-above-text-field-outlined 250ms 1;}.mdc-text-field--textarea .mdc-notched-outline .mdc-notched-outline__leading{border-radius:4px 0 0 4px;}[dir=rtl] .mdc-text-field--textarea .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--textarea .mdc-notched-outline .mdc-notched-outline__leading[dir=rtl]{border-radius:0 4px 4px 0;}.mdc-text-field--textarea .mdc-notched-outline .mdc-notched-outline__trailing{border-radius:0 4px 4px 0;}[dir=rtl] .mdc-text-field--textarea .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--textarea .mdc-notched-outline .mdc-notched-outline__trailing[dir=rtl]{border-radius:4px 0 0 4px;}.mdc-text-field--textarea::before,.mdc-text-field--textarea::after{content:none;}.mdc-text-field--textarea:not(.mdc-text-field--disabled){background-color:transparent;}.mdc-text-field--textarea .mdc-floating-label--float-above{-webkit-transform:translateY(-144%) scale(1);transform:translateY(-144%) scale(1);}.mdc-text-field--textarea .mdc-floating-label--float-above{font-size:0.75rem;}.mdc-text-field--textarea.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--textarea .mdc-notched-outline--upgraded .mdc-floating-label--float-above{-webkit-transform:translateY(-130%) scale(0.75);transform:translateY(-130%) scale(0.75);}.mdc-text-field--textarea.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--textarea .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem;}.mdc-text-field--textarea .mdc-text-field-character-counter{left:initial;right:16px;position:absolute;bottom:13px;}[dir=rtl] .mdc-text-field--textarea .mdc-text-field-character-counter,.mdc-text-field--textarea .mdc-text-field-character-counter[dir=rtl]{left:16px;right:initial;}.mdc-text-field--textarea .mdc-text-field__input{-ms-flex-item-align:auto;align-self:auto;-webkit-box-sizing:border-box;box-sizing:border-box;height:auto;margin:8px 1px 1px 0;padding:0 16px 16px;border:none;}.mdc-text-field--textarea .mdc-text-field-character-counter+.mdc-text-field__input{margin-bottom:28px;padding-bottom:0;}.mdc-text-field--textarea .mdc-floating-label{top:17px;bottom:auto;width:auto;pointer-events:none;}.mdc-text-field--textarea.mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--textarea.mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--textarea.mdc-text-field--focused .mdc-notched-outline__trailing{border-width:2px;}.mdc-text-field--fullwidth{width:100%;}.mdc-text-field--fullwidth:not(.mdc-text-field--textarea){display:block;}.mdc-text-field--fullwidth:not(.mdc-text-field--textarea)::before,.mdc-text-field--fullwidth:not(.mdc-text-field--textarea)::after{content:none;}.mdc-text-field--fullwidth:not(.mdc-text-field--textarea):not(.mdc-text-field--disabled){background-color:transparent;}.mdc-text-field--fullwidth:not(.mdc-text-field--textarea) .mdc-text-field__input{padding:0;}.mdc-text-field--fullwidth.mdc-text-field--textarea .mdc-text-field__input{resize:vertical;}.mdc-text-field--fullwidth.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--textarea){border-bottom-color:#b00020;border-bottom-color:var(--mdc-theme-error,#b00020);}.mdc-text-field-helper-line{display:-ms-flexbox;display:flex;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-sizing:border-box;box-sizing:border-box;}.mdc-text-field--dense+.mdc-text-field-helper-line{margin-bottom:4px;}.mdc-text-field+.mdc-text-field-helper-line{padding-right:16px;padding-left:16px;}.mdc-form-field > .mdc-text-field+label{-ms-flex-item-align:start;align-self:flex-start;}.mdc-text-field--focused:not(.mdc-text-field--disabled) .mdc-floating-label{color:rgba(98,0,238,0.87);}.mdc-text-field--focused .mdc-text-field__input:required ~ .mdc-floating-label::after,.mdc-text-field--focused .mdc-text-field__input:required ~ .mdc-notched-outline .mdc-floating-label::after{color:rgba(98,0,238,0.87);}.mdc-text-field--focused+.mdc-text-field-helper-line .mdc-text-field-helper-text:not(.mdc-text-field-helper-text--validation-msg){opacity:1;}.mdc-text-field--textarea.mdc-text-field--focused:not(.mdc-text-field--disabled) .mdc-notched-outline__leading,.mdc-text-field--textarea.mdc-text-field--focused:not(.mdc-text-field--disabled) .mdc-notched-outline__notch,.mdc-text-field--textarea.mdc-text-field--focused:not(.mdc-text-field--disabled) .mdc-notched-outline__trailing{border-color:#6200ee;border-color:var(--mdc-theme-primary,#6200ee);}.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--outlined):not(.mdc-text-field--textarea) .mdc-text-field__input{border-bottom-color:#b00020;border-bottom-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--outlined):not(.mdc-text-field--textarea) .mdc-text-field__input:hover{border-bottom-color:#b00020;border-bottom-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-line-ripple{background-color:#b00020;background-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-floating-label{color:#b00020;color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--invalid+.mdc-text-field-helper-line .mdc-text-field-helper-text--validation-msg{color:#b00020;color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid .mdc-text-field__input{caret-color:#b00020;caret-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid .mdc-text-field__input:required ~ .mdc-floating-label::after,.mdc-text-field--invalid .mdc-text-field__input:required ~ .mdc-notched-outline .mdc-floating-label::after{color:#b00020;color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid.mdc-text-field--with-trailing-icon:not(.mdc-text-field--with-leading-icon):not(.mdc-text-field--disabled) .mdc-text-field__icon{color:#b00020;color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid.mdc-text-field--with-trailing-icon.mdc-text-field--with-leading-icon:not(.mdc-text-field--disabled) .mdc-text-field__icon ~ .mdc-text-field__icon{color:#b00020;color:var(--mdc-theme-error,#b00020);}.mdc-text-field--invalid+.mdc-text-field-helper-line .mdc-text-field-helper-text--validation-msg{opacity:1;}.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__leading,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__notch,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__trailing{border-color:#b00020;border-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing{border-color:#b00020;border-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--textarea.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__trailing{border-color:#b00020;border-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__trailing{border-color:#b00020;border-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__input:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused) .mdc-text-field__icon:hover ~ .mdc-notched-outline .mdc-notched-outline__trailing{border-color:#b00020;border-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__trailing{border-color:#b00020;border-color:var(--mdc-theme-error,#b00020);}.mdc-text-field--disabled{background-color:#fafafa;border-bottom:none;pointer-events:none;}.mdc-text-field--disabled .mdc-text-field__input{border-bottom-color:rgba(0,0,0,0.06);}.mdc-text-field--disabled .mdc-text-field__input{color:rgba(0,0,0,0.37);}.mdc-text-field--disabled .mdc-floating-label{color:rgba(0,0,0,0.37);}.mdc-text-field--disabled+.mdc-text-field-helper-line .mdc-text-field-helper-text{color:rgba(0,0,0,0.37);}.mdc-text-field--disabled .mdc-text-field-character-counter,.mdc-text-field--disabled+.mdc-text-field-helper-line .mdc-text-field-character-counter{color:rgba(0,0,0,0.37);}.mdc-text-field--disabled .mdc-text-field__icon{color:rgba(0,0,0,0.3);}.mdc-text-field--disabled:not(.mdc-text-field--textarea){border-bottom-color:rgba(0,0,0,0.12);}.mdc-text-field--disabled .mdc-floating-label{cursor:default;}.mdc-text-field--textarea.mdc-text-field--disabled{background-color:transparent;background-color:#f9f9f9;}.mdc-text-field--textarea.mdc-text-field--disabled .mdc-notched-outline__leading,.mdc-text-field--textarea.mdc-text-field--disabled .mdc-notched-outline__notch,.mdc-text-field--textarea.mdc-text-field--disabled .mdc-notched-outline__trailing{border-color:rgba(0,0,0,0.06);}.mdc-text-field--textarea.mdc-text-field--disabled .mdc-text-field__input{border-bottom:none;}\@-webkit-keyframes mdc-floating-label-shake-float-above-text-field-dense{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(4% - 0%)) translateY(-70%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(-4% - 0%)) translateY(-70%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);}}\@keyframes mdc-floating-label-shake-float-above-text-field-dense{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(4% - 0%)) translateY(-70%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(-4% - 0%)) translateY(-70%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-70%) scale(0.8);}}\@-webkit-keyframes mdc-floating-label-shake-float-above-text-field-outlined{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}}\@keyframes mdc-floating-label-shake-float-above-text-field-outlined{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}}\@-webkit-keyframes mdc-floating-label-shake-float-above-text-field-outlined-dense{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(4% - 0%)) translateY(-120%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(-4% - 0%)) translateY(-120%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);}}\@keyframes mdc-floating-label-shake-float-above-text-field-outlined-dense{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(4% - 0%)) translateY(-120%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(-4% - 0%)) translateY(-120%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 0%)) translateY(-120%) scale(0.8);}}\@-webkit-keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon{0%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}}\@keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon{0%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}}\@-webkit-keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense{0%{-webkit-transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(4% - 21px)) translateY(-120%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(-4% - 21px)) translateY(-120%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);}}\@keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense{0%{-webkit-transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(4% - 21px)) translateY(-120%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(-4% - 21px)) translateY(-120%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - 21px)) translateY(-120%) scale(0.8);}}\@-webkit-keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-rtl{0%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}}\@keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-rtl{0%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0)) translateY(-130%) scale(0.75);}}\@-webkit-keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense-rtl{0%{-webkit-transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(4% - -21px)) translateY(-120%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(-4% - -21px)) translateY(-120%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);}}\@keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-dense-rtl{0%{-webkit-transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(4% - -21px)) translateY(-120%) scale(0.8);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(-4% - -21px)) translateY(-120%) scale(0.8);}100%{-webkit-transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);transform:translateX(calc(0 - -21px)) translateY(-120%) scale(0.8);}}\@-webkit-keyframes mdc-floating-label-shake-float-above-textarea{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}}\@keyframes mdc-floating-label-shake-float-above-textarea{0%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}33%{-webkit-animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);animation-timing-function:cubic-bezier(0.5,0,0.701732,0.495819);-webkit-transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(4% - 0%)) translateY(-130%) scale(0.75);}66%{-webkit-animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);animation-timing-function:cubic-bezier(0.302435,0.381352,0.55,0.956352);-webkit-transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(-4% - 0%)) translateY(-130%) scale(0.75);}100%{-webkit-transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);transform:translateX(calc(0 - 0%)) translateY(-130%) scale(0.75);}}.mdc-text-field-helper-text{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.75rem;line-height:1.25rem;font-weight:400;letter-spacing:0.0333333333em;text-decoration:inherit;text-transform:inherit;display:block;margin-top:0;line-height:normal;margin:0;-webkit-transition:opacity 150ms cubic-bezier(0.4,0,0.2,1);transition:opacity 150ms cubic-bezier(0.4,0,0.2,1);opacity:0;will-change:opacity;}.mdc-text-field-helper-text::before{display:inline-block;width:0;height:16px;content:\"\";vertical-align:0;}.mdc-text-field-helper-text--persistent{-webkit-transition:none;transition:none;opacity:1;will-change:initial;}.mdc-text-field--with-leading-icon .mdc-text-field__icon,.mdc-text-field--with-trailing-icon .mdc-text-field__icon{position:absolute;bottom:16px;cursor:pointer;}.mdc-text-field__icon:not([tabindex]),.mdc-text-field__icon[tabindex=\"-1\"]{cursor:default;pointer-events:none;}\@font-face{font-family:\"Material Icons\";font-style:normal;font-weight:400;src:url(MaterialIcons-Regular.eot);src:local(\"Material Icons\"),local(\"MaterialIcons-Regular\"),url(MaterialIcons-Regular.woff2) format(\"woff2\"),url(MaterialIcons-Regular.woff) format(\"woff\"),url(MaterialIcons-Regular.ttf) format(\"truetype\");}.material-icons{font-family:\"Material Icons\";font-weight:normal;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;-webkit-font-feature-settings:\"liga\";font-feature-settings:\"liga\";}:host{display:block;}:host input[readonly]{cursor:pointer;}.mdc-text-field--focused:not(.mdc-text-field--disabled):not(.mdc-text-field--invalid) .mdc-floating-label{color:#6200ee;color:var(--mdc-theme-primary,#6200ee);}.datepicker::-webkit-datetime-edit-text{padding:0 0.3em;}.datepicker::-webkit-inner-spin-button{display:none;}.datepicker::-webkit-clear-button,.datepicker::-ms-clear{display:none !important;}.datepicker::-webkit-calendar-picker-indicator{display:none;-webkit-appearance:none;}.date-picker{padding:16px;}.mdc-text-field{border-radius:var(--mdc-theme-text-field-filled-radius,4px) var(--mdc-theme-text-field-filled-radius,4px) 0 0;}.mdc-text-field.mdc-text-field--outlined .mdc-notched-outline__leading{border-radius:var(--mdc-theme-text-field-outlined-radius,4px) 0 0 var(--mdc-theme-text-field-outlined-radius,4px);}.mdc-text-field.mdc-text-field--outlined .mdc-notched-outline__trailing{border-radius:0 var(--mdc-theme-text-field-outlined-radius,4px) var(--mdc-theme-text-field-outlined-radius,4px) 0;}.mdc-text-field--overflow-elipsis{text-overflow:ellipsis;}:host(.materials-text-field--dense) .mdc-text-field{-webkit-transform:scale(0.8);transform:scale(0.8);-webkit-transform-origin:0% 0;transform-origin:0% 0;}:host(.materials-text-field--dense) .mdc-text-field .mdc-floating-label{font-size:1.25rem;}:host(.materials-text-field--dense) .mdc-text-field .mdc-select__native-control{font-size:1.25rem;}:host(.materials-text-field--dense) .mdc-text-field-helper-line{-webkit-transform:translateY(-50%);transform:translateY(-50%);}.hide-native-clear::-webkit-datetime-edit-text{padding:0 0.3em;}.hide-native-clear::-webkit-inner-spin-button{display:none;}.hide-native-clear::-webkit-clear-button,.hide-native-clear::-ms-clear{display:none !important;}.hide-native-clear::-webkit-calendar-picker-indicator{display:none;-webkit-appearance:none;}"; }
};

exports.materials_text_field = TextField;
